@@ -41,8 +41,7 @@ class TimeLabels : public QFrame
 public:
     typedef QList<TimeLabels *> List;
 
-    TimeLabels(const QTimeZone &zone, int rows, TimeLabelsZone *parent = nullptr,
-               Qt::WindowFlags f = nullptr);
+    TimeLabels(const QTimeZone &zone, int rows, TimeLabelsZone *parent = nullptr, Qt::WindowFlags f = nullptr);
 
     /** updates widget's internal state */
     void updateConfig();
@@ -57,23 +56,30 @@ public:
     void contextMenuEvent(QContextMenuEvent *event) override;
 
     /** Returns the time zone of this label */
-    QTimeZone timeZone() const;
+    Q_REQUIRED_RESULT QTimeZone timeZone() const;
 
     /**
       Return string which can be used as a header for the time label.
     */
-    QString header() const;
+    Q_REQUIRED_RESULT QString header() const;
 
     /**
       Return string which can be used as a tool tip for the header.
     */
-    QString headerToolTip() const;
+    Q_REQUIRED_RESULT QString headerToolTip() const;
 
     QSize sizeHint() const override;
 
     QSize minimumSizeHint() const override;
 
+    /** */
+    bool event(QEvent *event) override;
+
 private:
+    Q_REQUIRED_RESULT int yposToCell(const int ypos) const;
+    Q_REQUIRED_RESULT int cellToHour(const int cell) const;
+    Q_REQUIRED_RESULT QString cellToSuffix(const int cell) const;
+
     /** update the position of the marker showing the mouse position */
     void mousePosChanged(const QPoint &pos);
 
